@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------------
   ----- File:        parseAFM.c
   ----- Author:      Adobe Systems Inc., modifications by
-                     Rainer Menzner (rmz@neuroinformatik.ruhr-uni-bochum.de)
-  ----- Date:        1999-08-16
+                     Rainer Menzner (Rainer.Menzner@web.de)
+  ----- Date:        2001-04-01
   ----- Description: This file is part of the t1-library. It is the original
                      parseAFM.h modified at a few points, especially for
 		     reading MSDOS-style AFM files..
-  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-1998. 
+  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-2001.
                      As of version 0.5, t1lib is distributed under the
 		     GNU General Public Library Lincense. The
 		     conditions can be found in the files LICENSE and
@@ -82,7 +82,9 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <sys/types.h>  /* this seems to be necessary on some SCO-systems */
-#include <sys/file.h>
+#if !defined(_MSC_VER)
+#  include <sys/file.h>
+#endif
 #include <math.h>
 #include <string.h>
 #include "parseAFM.h"
